@@ -946,7 +946,7 @@ static void details_done (PkClient *client, GAsyncResult *res, gpointer data)
 
     gtk_widget_set_sensitive (close_btn, TRUE);
     gtk_widget_set_sensitive (apply_btn, TRUE);
-    gtk_widget_grab_focus (close_btn);
+    gtk_widget_grab_focus (apply_btn);
 
     gtk_widget_destroy (GTK_WIDGET (msg_dlg));
     msg_dlg = NULL;
@@ -1444,7 +1444,6 @@ static void category_selected (GtkTreeView *tv, gpointer ptr)
     GtkTreeModel *model;
     GtkTreePath *path;
     GtkTreeSelection *sel;
-    GtkTreeViewColumn *col;
     GtkTreeIter iter;
 
     // store the path of the new selection so it can be reloaded
@@ -1459,10 +1458,9 @@ static void category_selected (GtkTreeView *tv, gpointer ptr)
 
     model = gtk_tree_view_get_model (GTK_TREE_VIEW (pack_tv));
     path = gtk_tree_path_new_first ();
-    col = gtk_tree_view_get_column (GTK_TREE_VIEW (pack_tv), 2);
     gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (model));
     gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (pack_tv), path, NULL, TRUE, 0.0, 0.0);
-    gtk_tree_view_set_cursor (GTK_TREE_VIEW (pack_tv), path, col, FALSE);
+    gtk_tree_view_set_cursor (GTK_TREE_VIEW (pack_tv), path, NULL, FALSE);
     gtk_tree_path_free (path);
 }
 
